==> zio-aws-route53recoverycontrolconfig_2.12-5.17.177.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteClusterRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteClusterRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest = {
    import DeleteClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest
      .wrap(buildAwsValue())
}
object DeleteClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteClusterRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.17.128.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteClusterRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteClusterRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest = {
    import DeleteClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
      .builder()
      .clusterArn(__string.unwrap(clusterArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest
      .wrap(buildAwsValue())
}
object DeleteClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteClusterRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest.ReadOnly {
    override val clusterArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.clusterArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteClusterRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteClusterRequest.ReadOnly =
    new Wrapper(impl)
}
